export declare type MountType = 'bind' | 'volume' | 'tmpfs';
export declare type DeviceRequest = {
    Driver?: string;
    Count?: number;
    DeviceIDs?: string[];
    Capabilities?: string[][];
    Options?: {
        [key: string]: string;
    };
};
export declare type MountSettings = {
    Target: string;
    Source: string;
    Type: MountType;
    ReadOnly?: boolean;
    VolumeOptions?: {
        NoCopy: boolean;
        Labels: {
            [label: string]: string;
        };
        DriverConfig: {
            Name: string;
            Options: {
                [option: string]: string;
            };
        };
    };
    TmpfsOptions?: {
        SizeBytes: number;
        Mode: number;
    };
};
export declare type MountConfig = MountSettings[];
export declare type HostConfig = {
    AutoRemove?: boolean;
    Binds?: string[];
    ContainerIDFile?: string;
    LogConfig?: {
        Type: string;
        Config: any;
    };
    NetworkMode?: string;
    PortBindings?: any;
    VolumeDriver?: string;
    VolumesFrom?: any;
    Mounts?: MountConfig;
    CapAdd?: any;
    CapDrop?: any;
    Dns?: any[];
    DnsOptions?: any[];
    DnsSearch?: any[];
    ExtraHosts?: any;
    GroupAdd?: string[];
    IpcMode?: string;
    Cgroup?: string;
    Links?: any;
    OomScoreAdj?: number;
    PidMode?: string;
    Privileged?: boolean;
    PublishAllPorts?: boolean;
    ReadonlyRootfs?: boolean;
    SecurityOpt?: any;
    StorageOpt?: {
        [option: string]: string;
    };
    Tmpfs?: {
        [dir: string]: string;
    };
    UTSMode?: string;
    UsernsMode?: string;
    ShmSize?: number;
    Sysctls?: {
        [index: string]: string;
    };
    Runtime?: string;
    ConsoleSize?: number[];
    Isolation?: string;
    MaskedPaths?: string[];
    ReadonlyPaths?: string[];
    CpuShares?: number;
    CgroupParent?: string;
    BlkioWeight?: number;
    BlkioWeightDevice?: any;
    BlkioDeviceReadBps?: any;
    BlkioDeviceWriteBps?: any;
    BlkioDeviceReadIOps?: any;
    BlkioDeviceWriteIOps?: any;
    CpuPeriod?: number;
    CpuQuota?: number;
    CpusetCpus?: string;
    CpusetMems?: string;
    Devices?: any;
    DeviceCgroupRules?: string[];
    DeviceRequests?: DeviceRequest[];
    DiskQuota?: number;
    KernelMemory?: number;
    Memory?: number;
    MemoryReservation?: number;
    MemorySwap?: number;
    MemorySwappiness?: number;
    OomKillDisable?: boolean;
    PidsLimit?: number;
    Ulimits?: any;
};
export declare type CreateOptions = {
    name?: string;
    Hostname?: string;
    Domainname?: string;
    User?: string;
    AttachStdin?: boolean;
    AttachStdout?: boolean;
    AttachStderr?: boolean;
    Tty?: boolean;
    OpenStdin?: boolean;
    StdinOnce?: boolean;
    Env?: string[];
    Cmd?: string[];
    Entrypoint?: string | string[];
    Image?: string;
    Labels?: {
        [label: string]: string;
    };
    Volumes?: {
        [volume: string]: unknown;
    };
    WorkingDir?: string;
    NetworkDisabled?: boolean;
    MacAddress?: boolean;
    ExposedPorts?: {
        [port: string]: unknown;
    };
    StopSignal?: string;
    StopTimeout?: number;
    HostConfig?: HostConfig;
};
